from attr import dataclass


@dataclass
class PPPAAA:
    accounting: bool
    interim_update: str
    use_circuit_id_in_nas_port_id: bool
    use_radius: bool
    enable_ipv6_accounting: bool = None
